@@ -10,7 +10,6 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
-	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
 	"io"
 	"os"
 	"os/exec"
@@ -18,6 +17,8 @@ import (
 	"strconv"
 	"strings"
 	"time"
+
+	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
 )
 
 type APTSystem struct {
@@ -179,7 +180,20 @@ func CheckPkgSystemError(lock bool) error {
 	cmd.Stdout = &outBuf
 	var errBuf bytes.Buffer
 	cmd.Stderr = &errBuf
-	err := cmd.Run()
+	ff, err := system.OpenFlush(system.FlushName)
+	if err == nil {
+		defer func() {
+			ff.WriteString(fmt.Sprintf("=== CheckPkg %v end ===\n", cmd.Args))
+			ff.Close()
+		}()
+
+		err = ff.SetFlushCmd(cmd)
+		if err != nil {
+			logger.Warning(err)
+		}
+	}
+	ff.WriteString(fmt.Sprintf("=== CheckPkg cmd running: %v ===\n", cmd.Args))
+	err = cmd.Run()
 	if err == nil {
 		return nil
 	}
@@ -268,6 +282,7 @@ func (p *APTSystem) Remove(jobId string, packages []string, environ map[string]s
 	}
 
 	c := newAPTCommand(p, jobId, system.RemoveJobType, p.Indicator, packages)
+	environ["IMMUTABLE_DISABLE_REMOUNT"] = "false"
 	c.SetEnv(environ)
 	return safeStart(c)
 }
@@ -279,6 +294,7 @@ func (p *APTSystem) Install(jobId string, packages []string, environ map[string]
 		return err
 	}
 	c := newAPTCommand(p, jobId, system.InstallJobType, p.Indicator, append(OptionToArgs(args), packages...))
+	environ["IMMUTABLE_DISABLE_REMOUNT"] = "false"
 	c.SetEnv(environ)
 	return safeStart(c)
 }
@@ -295,6 +311,7 @@ func (p *APTSystem) DistUpgrade(jobId string, packages []string, environ map[str
 		}
 	}
 	c := newAPTCommand(p, jobId, system.DistUpgradeJobType, p.Indicator, append(OptionToArgs(args), packages...))
+	environ["IMMUTABLE_DISABLE_REMOUNT"] = "false"
 	c.SetEnv(environ)
 	return safeStart(c)
 }
@@ -339,6 +356,7 @@ func (p *APTSystem) AbortWithFailed(jobId string) error {
 func (p *APTSystem) FixError(jobId string, errType string, environ map[string]string, args map[string]string) error {
 	WaitDpkgLockRelease()
 	c := newAPTCommand(p, jobId, system.FixErrorJobType, p.Indicator, append([]string{errType}, OptionToArgs(args)...))
+	environ["IMMUTABLE_DISABLE_REMOUNT"] = "false"
 	c.SetEnv(environ)
 	if system.JobErrorType(errType) == system.ErrorDependenciesBroken { // 修复依赖错误的时候，会有需要卸载dde的情况，因此需要用safeStart来进行处理
 		return safeStart(c)
@@ -544,5 +562,9 @@ func (p *APTSystem) OsBackup(jobId string) error {
 			Cancelable:  false,
 		}, nil
 	}
+	environ := map[string]string{
+		"IMMUTABLE_DISABLE_REMOUNT": "false",
+	}
+	c.SetEnv(environ)
 	return c.Start()
 }
