@@ -14,7 +14,6 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
-	"github.com/linuxdeepin/lastore-daemon/src/internal/system/dut"
 	"io"
 	"net/http"
 	"net/url"
@@ -26,6 +25,8 @@ import (
 	"sync"
 	"time"
 
+	"github.com/linuxdeepin/lastore-daemon/src/internal/system/dut"
+
 	"github.com/godbus/dbus/v5"
 	ConfigManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
 	"github.com/linuxdeepin/go-lib/keyfile"
@@ -1052,30 +1053,41 @@ func (m *UpdatePlatformManager) updateLogMetaSync() error {
 			osBuildSlice := strings.Split(osBuild, ".")
 			var secVersionStr string
 			if len(osBuildSlice) >= 3 {
-				secVersionStr = osBuildSlice[1]
-				secVersionInt, err := strconv.Atoi(secVersionStr)
-				if err != nil {
-					logger.Warning(err)
-					return nil
-				}
-				realSecVersion := secVersionInt - 100
-				minorVersionInt, err := strconv.Atoi(minorVersion)
-				if err != nil {
-					logger.Warning(err)
-					return nil
-				}
-				globalVersion := minorVersionInt + realSecVersion
-				if globalVersion < 1000 {
-					logger.Warningf("system version is %v, not support compare with %v", globalVersion, m.targetVersion)
-					return nil
-				}
-				targetVersionInt, err := strconv.Atoi(m.targetVersion)
-				if err != nil {
-					logger.Warning(err)
-					return nil
+				var globalVersionStr string
+				var ok bool
+				// 社区版的version是minorVersion，直接可以显示小版本
+				if osVersionInfoMap["EditionName"] == "Community" {
+					ok = true
+				} else {
+					secVersionStr = osBuildSlice[1]
+					secVersionInt, err := strconv.Atoi(secVersionStr)
+					if err != nil {
+						logger.Warning(err)
+						return nil
+					}
+					realSecVersion := secVersionInt - 100
+					minorVersionInt, err := strconv.Atoi(minorVersion)
+					if err != nil {
+						logger.Warning(err)
+						return nil
+					}
+					globalVersion := minorVersionInt + realSecVersion
+					if globalVersion < 1000 {
+						logger.Warningf("system version is %v, not support compare with %v", globalVersion, m.targetVersion)
+						return nil
+					}
+					targetVersionInt, err := strconv.Atoi(m.targetVersion)
+					if err != nil {
+						logger.Warning(err)
+						return nil
+					}
+					if targetVersionInt > globalVersion {
+						ok = true
+					}
+					globalVersionStr = fmt.Sprintf("%v", globalVersion)
 				}
 				logData := getUpdateLogData(data)
-				if targetVersionInt > globalVersion {
+				if ok {
 					m.SystemUpdateLogs = logData
 				} else {
 					var lastLog UpdateLogMeta
@@ -1085,7 +1097,7 @@ func (m *UpdatePlatformManager) updateLogMetaSync() error {
 
 					m.SystemUpdateLogs = append(m.SystemUpdateLogs, UpdateLogMeta{
 						Baseline:      lastLog.Baseline,
-						ShowVersion:   fmt.Sprintf("%v", globalVersion),
+						ShowVersion:   globalVersionStr,
 						CnLog:         "修复部分系统已知问题与缺陷",
 						EnLog:         "Fixing some of the system's known problems and defects",
 						LogType:       lastLog.LogType,
