@@ -11,8 +11,6 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
-	"github.com/linuxdeepin/lastore-daemon/src/internal/config"
-	"github.com/linuxdeepin/lastore-daemon/src/internal/system/dut"
 	"net/url"
 	"os"
 	"os/exec"
@@ -22,6 +20,9 @@ import (
 	"syscall"
 	"time"
 
+	"github.com/linuxdeepin/lastore-daemon/src/internal/config"
+	"github.com/linuxdeepin/lastore-daemon/src/internal/system/dut"
+
 	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
 	"github.com/linuxdeepin/lastore-daemon/src/internal/updateplatform"
 
@@ -283,7 +284,7 @@ func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, isClas
 			job.option["Dir::State::lists"] = system.OfflineListPath
 		}
 
-		if mode == system.UnknownUpdate {
+		if m.supportDpkgScriptIgnore && mode == system.UnknownUpdate {
 			job.option["DPkg::Options::"] = "--script-ignore-error"
 		}
 
@@ -547,12 +548,27 @@ func (m *Manager) preFailedHook(job *Job, mode system.UpdateType, uuid string) e
 // 格式化输出需要添加-j 参数
 func osTreeCmd(args []string) (out string, err error) {
 	if system.NormalFileExists(DEEPIN_IMMUTABLE_CTL) {
-		cmd := exec.Command(DEEPIN_IMMUTABLE_CTL, args...)
+		args = append(args, "-v")
+		cmd := exec.Command(DEEPIN_IMMUTABLE_CTL, args...) // #nosec G204
+		cmd.Env = append(os.Environ(), "IMMUTABLE_DISABLE_REMOUNT=false")
 		logger.Info("run command:", cmd.Args)
 		var stdout, stderr bytes.Buffer
 		cmd.Stdout = &stdout
 		cmd.Stderr = &stderr
-		err := cmd.Run()
+		ff, err := system.OpenFlush(system.FlushName)
+		if err == nil {
+			defer func() {
+				ff.WriteString(fmt.Sprintf("=== Ostree %v end ===\n", cmd.Args))
+				ff.Close()
+			}()
+
+			err = ff.SetFlushCmd(cmd)
+			if err != nil {
+				logger.Warning(err)
+			}
+		}
+		ff.WriteString(fmt.Sprintf("=== Ostree cmd running: %v ===\n", cmd.Args))
+		err = cmd.Run()
 		if err != nil {
 			return "", fmt.Errorf("%v", stderr.String())
 		} else {
@@ -569,10 +585,11 @@ type ostreeError struct {
 }
 
 type ostreeRollbackData struct {
-	Version     int  `json:"version"`
-	CanRollback bool `json:"can_rollback"`
-	//Time        int64  `json:"time"`
-	//Name        string `json:"name"`
+	Version     int    `json:"version"`
+	CanRollback bool   `json:"can_rollback"`
+	Time        int64  `json:"time"`
+	Name        string `json:"name"`
+	Auto        bool   `json:"auto"`
 }
 
 type ostreeResponse struct {
@@ -606,25 +623,57 @@ func osTreeRollback() error {
 	return nil
 }
 
-func osTreeCanRollback() (bool, string) {
+func osTreeParseRollbackData() (*ostreeRollbackData, error) {
 	out, err := osTreeCmd([]string{"admin", "rollback", "--can-rollback", "-j"})
 	if err != nil {
-		logger.Warning(err)
-		return false, ""
+		logger.Warning("osTreeCmd failed:", err)
+		return nil, err
 	}
-	logger.Info(out)
+
+	logger.Info("osTree rollback output:", out)
+
 	var resp ostreeResponse
 	err = json.Unmarshal([]byte(out), &resp)
-	if err == nil && resp.Error == nil {
-		var data ostreeRollbackData
-		if err = json.Unmarshal(resp.Data, &data); err != nil {
-			logger.Warning(err)
-		}
-		return data.CanRollback, string(resp.Data)
-	} else {
-		logger.Warning("ostree Unmarshal data failed", err)
+	if err != nil {
+		logger.Warning("unmarshal ostree response failed:", err)
+		return nil, err
 	}
-	return false, ""
+
+	if resp.Error != nil {
+		logger.Warning("ostree response has error:", resp.Error)
+		return nil, fmt.Errorf("ostree error: %v", resp.Error)
+	}
+
+	var data ostreeRollbackData
+	err = json.Unmarshal(resp.Data, &data)
+	if err != nil {
+		logger.Warning("unmarshal rollback data failed:", err)
+		return nil, err
+	}
+
+	return &data, nil
+}
+
+func osTreeCanRollback() (bool, string) {
+	data, err := osTreeParseRollbackData()
+	if err != nil {
+		return false, ""
+	}
+
+	rawData, err := json.Marshal(data)
+	if err != nil {
+		return data.CanRollback, ""
+	}
+
+	return data.CanRollback, string(rawData)
+}
+
+func osTreeIsAutoRollback() bool {
+	data, err := osTreeParseRollbackData()
+	if err != nil {
+		return false
+	}
+	return data.Auto
 }
 
 func (m *Manager) preUpgradeCmdSuccessHook(job *Job, needChangeGrub bool, mode system.UpdateType, uuid string) error {
